@@ -11,10 +11,11 @@ class BGPConfig(PluginConfig):
     author_email = 'mgk.kolek@gmail.com'
     base_url = 'bgp'
     required_settings = []
-    min_version = '2.10.1'
-    max_version = '2.11.12'
+    min_version = '3.0.0'
+    max_version = '3.0.10'
     default_settings = {
-        'device_ext_page': 'right'
+        'device_ext_page': 'right',
+        'asdot': False
     }
 
 
