@@ -64,7 +64,13 @@ class ASNSerializer(TaggedObjectSerializer, CustomFieldModelSerializer):
     tenant = NestedTenantSerializer(required=False, allow_null=True)
 
     def validate(self, attrs):
-        if ASN.objects.filter(number=attrs['number'], tenant=attrs.get('tenant')).exists():
+        try:
+            number = attrs['number']
+            tenant = attrs.get('tenant')
+        except KeyError:
+            # this is patch
+            return attrs
+        if ASN.objects.filter(number=number, tenant=tenant).exists():
             raise ValidationError(
                 {'error': 'Asn with this Number and Tenant already exists.'}
             )
@@ -72,7 +78,7 @@ class ASNSerializer(TaggedObjectSerializer, CustomFieldModelSerializer):
 
     class Meta:
         model = ASN
-        fields = ['number', 'id', 'status', 'description', 'custom_fields', 'site', 'tenant', 'tags']
+        fields = ['number', 'id', 'display', 'status', 'description', 'custom_fields', 'site', 'tenant', 'tags']
 
 
 class NestedASNSerializer(WritableNestedSerializer):
@@ -155,6 +161,21 @@ class BGPSessionSerializer(TaggedObjectSerializer, CustomFieldModelSerializer):
     class Meta:
         model = BGPSession
         fields = '__all__'
+        validators = []
+
+    def validate(self, attrs):
+        qs = BGPSession.objects.filter(
+            device=attrs.get('device'),
+            local_as=attrs.get('local_as'),
+            local_address=attrs.get('local_address'),
+            remote_as=attrs.get('remote_as'),
+            remote_address=attrs.get('remote_address'),
+        )
+        if qs.exists():
+            raise ValidationError(
+                {'error': 'BGP Session with this Device, Local address, Local AS, Remote address and Remote AS already exists.'}
+            )
+        return attrs
 
     def to_representation(self, instance):
         ret = super().to_representation(instance)
