@@ -2,11 +2,7 @@ import django_filters
 import netaddr
 from django.db.models import Q
 from netaddr.core import AddrFormatError
-# With netbox v2.11.3 TagFilter was moved to extras
-try:
-    from utilities.filters import TagFilter
-except ImportError:
-    from extras.filters import TagFilter
+from extras.filters import TagFilter
 
 from .models import ASN, Community, BGPSession, RoutingPolicy, BGPPeerGroup
 from ipam.models import IPAddress
