@@ -49,11 +49,11 @@ urlpatterns = [
     path('routing-policy/<int:pk>/delete/', RoutingPolicyDeleteView.as_view(), name='routing_policy_delete'),
     path('routing-policy/<int:pk>/changelog/', ObjectChangeLogView.as_view(), name='routing_policy_changelog', kwargs={'model': RoutingPolicy}),
     # Peer Groups
-    path('peer-group/', BGPPeerGroupListView.as_view(), name='peer_group_list'),
-    path('peer-group/add/', BGPPeerGroupEditView.as_view(), name='peer_group_add'),
-    path('peer-group/delete/', BGPPeerGroupBulkDeleteView.as_view(), name='peer_group_bulk_delete'),
-    path('peer-group/<int:pk>/', BGPPeerGroupView.as_view(), name='peer_group'),
-    path('peer-group/<int:pk>/edit/', BGPPeerGroupEditView.as_view(), name='peer_group_edit'),
-    path('peer-group/<int:pk>/delete/', BGPPeerGroupDeleteView.as_view(), name='peer_group_delete'),
-    path('peer-group/<int:pk>/changelog/', ObjectChangeLogView.as_view(), name='peer_group_changelog', kwargs={'model': BGPPeerGroup}),
+    path('peer-group/', BGPPeerGroupListView.as_view(), name='peergroup_list'),
+    path('peer-group/add/', BGPPeerGroupEditView.as_view(), name='peergroup_add'),
+    path('peer-group/delete/', BGPPeerGroupBulkDeleteView.as_view(), name='peergroup_bulk_delete'),
+    path('peer-group/<int:pk>/', BGPPeerGroupView.as_view(), name='peergroup'),
+    path('peer-group/<int:pk>/edit/', BGPPeerGroupEditView.as_view(), name='peergroup_edit'),
+    path('peer-group/<int:pk>/delete/', BGPPeerGroupDeleteView.as_view(), name='peergroup_delete'),
+    path('peer-group/<int:pk>/changelog/', ObjectChangeLogView.as_view(), name='peergroup_changelog', kwargs={'model': BGPPeerGroup}),
 ]
